@@ -6,6 +6,13 @@
 
 char _license[] SEC("license") = "GPL";
 
+struct {
+	__uint(type, BPF_MAP_TYPE_ARRAY);
+	__uint(key_size, sizeof(u32));
+	__uint(value_size, sizeof(u32));
+	__uint(max_entries, 1);
+} test_counter_map SEC(".maps");
+
 SEC("struct_ops/test_1")
 int BPF_PROG(test_1, struct bpf_dummy_ops_state *state)
 {
@@ -22,8 +29,8 @@ int BPF_PROG(test_1, struct bpf_dummy_ops_state *state)
 __u64 test_2_args[5];
 
 SEC("struct_ops/test_2")
-int BPF_PROG(test_2, struct bpf_dummy_ops_state *state, int a1, unsigned short a2,
-	     char a3, unsigned long a4)
+int BPF_PROG(test_2, struct bpf_dummy_ops_state *state, int a1,
+	     unsigned short a2, char a3, unsigned long a4)
 {
 	test_2_args[0] = (unsigned long)state;
 	test_2_args[1] = a1;
@@ -33,6 +40,18 @@ int BPF_PROG(test_2, struct bpf_dummy_ops_state *state, int a1, unsigned short a
 	return 0;
 }
 
+SEC("xdp")
+int xdp_counter(struct xdp_md *ctx)
+{
+	u32 key = 0;
+	u32 *value = bpf_map_lookup_elem(&test_counter_map, &key);
+	if (value) {
+		*value += 1;
+		return XDP_PASS;
+	}
+	return XDP_DROP;
+}
+
 SEC(".struct_ops")
 struct bpf_dummy_ops dummy_1 = {
 	.test_1 = (void *)test_1,
